@@ -28,8 +28,10 @@ Foreigner::Adapter.register 'mysql', 'foreigner/connection_adapters/mysql_adapte
 Foreigner::Adapter.register 'mysql2', 'foreigner/connection_adapters/mysql2_adapter'
 Foreigner::Adapter.register 'jdbcmysql', 'foreigner/connection_adapters/mysql2_adapter'
 Foreigner::Adapter.register 'postgresql', 'foreigner/connection_adapters/postgresql_adapter'
+Foreigner::Adapter.register 'postgis', 'foreigner/connection_adapters/postgresql_adapter'
 Foreigner::Adapter.register 'jdbcpostgresql', 'foreigner/connection_adapters/postgresql_adapter'
 Foreigner::Adapter.register 'sqlite3', 'foreigner/connection_adapters/noop_adapter'
 
 require 'foreigner/loader'
+require 'foreigner/helper'
 require 'foreigner/railtie' if defined?(Rails)
