@@ -1,11 +1,20 @@
 require 'helper'
 
-ActiveRecord::Migration::CommandRecorder.class_eval do
-  include ::Foreigner::Migration::CommandRecorder
+if defined?(ActiveRecord::Migration::CommandRecorder)
+  ActiveRecord::Migration::CommandRecorder.class_eval do
+    include ::Foreigner::Migration::CommandRecorder
+  end
 end
 
 class Foreigner::CommandRecorderTest < Foreigner::UnitTest
+
+  def revert_exists?
+    defined?(ActiveRecord::Migration::CommandRecorder) &&
+      ActiveRecord::Migration::CommandRecorder.instance_methods.include?(:revert)
+  end
+
   setup do
+    skip unless revert_exists?
     @recorder = ActiveRecord::Migration::CommandRecorder.new
   end
 
@@ -48,4 +57,4 @@ class Foreigner::CommandRecorderTest < Foreigner::UnitTest
       # @recorder.inverse
     # end
   end
-end
\ No newline at end of file
+end
